@@ -35,7 +35,7 @@ def enable_logging(info=False):
         format="%(name)s (%(levelname)s): %(message)s")
 
 
-def main():
+def main(args=None):
     """
     'protontricks' script entrypoint
     """
@@ -93,7 +93,7 @@ def main():
         version="%(prog)s ({})".format(__version__)
     )
 
-    args = parser.parse_args()
+    args = parser.parse_args(args)
 
     do_command = bool(args.command)
     do_search = bool(args.search)
@@ -122,10 +122,8 @@ def main():
 
     # 2. Find Steam Runtime if enabled
     steam_runtime_path = None
-    runtime_enabled = False
 
     if os.environ.get("STEAM_RUNTIME", "") != "0" and not args.no_runtime:
-        runtime_enabled = True
         steam_runtime_path = find_steam_runtime_path(steam_root=steam_root)
 
         if not steam_runtime_path:
@@ -134,10 +132,6 @@ def main():
     else:
         logger.info("Steam Runtime disabled.")
 
-    if runtime_enabled and not steam_runtime_path:
-        print("Steam Runtime not found!")
-        sys.exit(-1)
-
     # 3. Find Winetricks
     winetricks_path = get_winetricks_path()
     if not winetricks_path:
@@ -151,7 +145,10 @@ def main():
     steam_lib_paths = get_steam_lib_paths(steam_path)
 
     # 5. Find any Steam apps
-    steam_apps = get_steam_apps(steam_root, steam_lib_paths)
+    steam_apps = get_steam_apps(
+        steam_root=steam_root, steam_path=steam_path,
+        steam_lib_paths=steam_lib_paths
+    )
 
     # It's too early to find Proton here,
     # as it cannot be found if no globally active Proton version is set.
