@@ -6,7 +6,6 @@ import re
 import string
 import struct
 import zlib
-
 from pathlib import Path
 
 import vdf
@@ -561,20 +560,34 @@ def get_steam_lib_paths(steam_path):
     return [steam_path] + library_folders
 
 
-def get_custom_proton_installations(steam_root):
+def get_compat_tool_dirs(steam_root):
+    # The path list is ordered by priority, starting from Proton apps
+    # with the lowest precedence ('/usr/share/steam/compatibilitytools.d')
+    paths = [
+        "/usr/share/steam/compatibilitytools.d",
+        "/usr/local/share/steam/compatibilitytools.d",
+    ]
+    extra_ct_paths_env = os.getenv("STEAM_EXTRA_COMPAT_TOOLS_PATHS")
+    if extra_ct_paths_env:
+        paths += extra_ct_paths_env.split(os.pathsep)
+    paths += [os.path.join(steam_root, "compatibilitytools.d")]
+
+    return paths
+
+
+def get_proton_installations(compat_tool_dir):
     """
     Return a list of custom Proton installations as a list of SteamApp objects
     """
-    comp_root = os.path.join(steam_root, "compatibilitytools.d")
 
-    if not os.path.isdir(comp_root):
+    if not os.path.isdir(compat_tool_dir):
         return []
 
     comptool_files = glob.glob(
-        os.path.join(comp_root, "*", "compatibilitytool.vdf")
+        os.path.join(compat_tool_dir, "*", "compatibilitytool.vdf")
     )
     comptool_files += glob.glob(
-        os.path.join(comp_root, "compatibilitytool.vdf")
+        os.path.join(compat_tool_dir, "compatibilitytool.vdf")
     )
 
     custom_proton_apps = []
@@ -602,7 +615,7 @@ def get_custom_proton_installations(steam_root):
         if install_path == ".":
             install_path = os.path.dirname(vdf_path)
         else:
-            install_path = os.path.join(comp_root, install_path)
+            install_path = os.path.join(compat_tool_dir, install_path)
 
         custom_proton_apps.append(
             SteamApp(name=internal_name, install_path=install_path)
@@ -611,6 +624,21 @@ def get_custom_proton_installations(steam_root):
     return custom_proton_apps
 
 
+def get_custom_proton_installations(steam_root):
+    custom_proton_apps = {}
+    for d in get_compat_tool_dirs(steam_root=steam_root):
+        for proton_app in get_proton_installations(d):
+            # If another Proton app exists with the same name, it will
+            # be replaced with an installation that has higher precedence
+            # here
+            custom_proton_apps[proton_app.name] = proton_app
+
+    # Return the list of Proton apps as a list
+    custom_proton_apps = list(custom_proton_apps.values())
+
+    return custom_proton_apps
+
+
 def find_current_steamid3(steam_path):
     def to_steamid3(steamid64):
         """Convert a SteamID64 into the SteamID3 format"""
